<?php
/*
Plugin Name: NTT Featured Content
Plugin URI: http://www.newthinktank.com/wordpress-featured-content-plugin/
Description: It displays a featured content slider on a web page. It was created to show how to create widgets and plugins. 

For it to function the Featured Picture must have the same name as the title of the post. That post also must be in the category named Featured.

Version: 2.0
Author: Derek Banas
Author URI: http://www.newthinktank.com
License: GPL3
*/
?>
<?php
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
?>
<?php

// __FILE__ reference to the plugin file itself
// The second parameter is the function to call when plugin is activated
register_activation_hook( __FILE__, 'ntt_featured_content_install' );

function ntt_featured_content_install()
{

	// Verify that the current wordpress version is at least 3
	if ( version_compare( get_bloginfo( 'version' ), '3.0', '<' ) )
	{
		// Deactivate your plugin
		deactivate_plugins( basename( __FILE__ ) );
	}
	
	// Create a variable that stores the number of featured posts
	// Set this to 0 by default
	$ntt_featured_images = array(
		'num_featured_posts' => 0
	);
	
	update_option( '$ntt_featured_images', $ntt_featured_images);

}

?>
<?php

// When wordpress checks to see if anything should be added to the editing 
// screens my function is called to create the meta box
add_action( 'add_meta_boxes', 'ntt_mbe_image_create' ); 

function ntt_mbe_image_create() { 

// add_meta_box tells wordpress to display a meta box 
// 1st parameter: the div id that surrounds the meta box
// 2nd parameter: the name displayed for your meta box
// 3rd parameter: function that displays your meta box
// 4th parameter: the page to display your meta box on ('post', 'page')
// 5th parameter: where to display the meta box ('normal', 'side')
// 6th parameter: priority of meta box ('high', 'low')
// 7th parameter: arguments to pass to the function above if any

add_meta_box( 'ntt-image-meta', 'Set Image', 'ntt_mbe_image_function', 'post', 'normal', 'high' ); 

}
?>
<?php
function ntt_mbe_image_function( $post ) { 

// Outputs a message to the user
echo 'Define your Featured Content Image Here. The dimensions of the image must be 576 × 240! <br /><br />To display the Featured image don\'t forget to mark this post under Featured in your categories.<br /><br />';

// Check if the current post is in the Featured category
if( in_category('Featured') ){
	echo 'In featured Category<br /><br />';
} else {
	echo 'Not in featured Category<br /><br />';
}

// Retrieve the number of currently Featured posts
$postsFeatured = get_term_by('name', 'Featured', 'category');
echo "Featured Posts: ", $postsFeatured->count, "<br /><br />";

// Check if a meta value has already been assigned for the featured image
// get_post_meta returns a value from a custom field
$ntt_mbe_image = get_post_meta( $post->ID, '_ntt_mbe_image', true ); 
?> 

<!-- Creating the input field for the featured image 
esc_url() sanitizes the image url and encodes HTML entities -->
<br /><br /><input id="ntt_mbe_image" type="text" size="75" name="ntt_mbe_image" value="<?php echo esc_url( $ntt_mbe_image ); ?>" /> 
<input id="upload_image_button" type="button" value="Media Library Image" class="button-secondary" /> <br />
<?php 

// Get an object that contains all posts in the category Featured
$postsFeatured = get_term_by('name', 'Featured', 'category');

// if( in_category('Featured') AND ($ntt_posts_featured > 5) ){

	// Make sure I only retrieve a maximum of 15 posts
	$ntt_posts_featured = (($postsFeatured->count) > 15) ? 15 : ($postsFeatured->count);

	// Call the function that will create the featured content
	ntt_make_fc_pages($ntt_posts_featured);


} 
?>
<?php
// This function creates all of the featured content code
function ntt_make_fc_pages($ntt_num_fc_pages) {

// Figure out how many featured content pages I should make
// knowing I need a minimum of 5 posts per page
$ntt_fc_pages = floor($ntt_num_fc_pages / 5);

$ntt_fc_info = array();

// Get the url for the plugin
$ntt_plugin_directory = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));

// Issue a custom query that outputs the titles for all featured articles
// To issue queries I need to hijack $wp_query. So, I can use it later
// on the page I'm saving it to a temporary variable
$tempWPQuery = $wp_query;
$wp_query = null;

// Create a new WP_Query Object
$wp_query = new WP_Query();

// Get the total number of posts to retreive
$postsFeatured = $ntt_fc_pages * 5;

// Issue a query that returns all posts in the category Featured
$wp_query->query('posts_per_page='.$postsFeatured.'&category_name=Featured');

// Cycle through all of the posts

$ntt_post_num = 1;
while ($wp_query->have_posts()):
	$wp_query->the_post();
	
	// Output the title of the post
	$ntt_fc_info[$ntt_post_num][0] = get_the_title($post->ID);
	
	// Retrieve the value of the excerpt and trim it to 330 characters
	$ntt_long_excerpt = get_the_excerpt();
	$ntt_short_excerpt = substr($ntt_long_excerpt, 0, 330);
	$ntt_fc_info[$ntt_post_num][1] = $ntt_short_excerpt;
	
	// Output the link url for the post
	$ntt_fc_info[$ntt_post_num][2] = get_permalink($post->ID);
	
	// Retrieve the url for the featured image which is saved as a meta value
	$ntt_post_id = get_the_ID();
	$ntt_featured_image = get_post_meta( $ntt_post_id, '_ntt_mbe_image', true );
	$ntt_fc_info[$ntt_post_num][3] = $ntt_featured_image;
	
	$ntt_fc_info[$ntt_post_num][4] = '<img src="' . $ntt_featured_image . '" alt="' . $ntt_fc_info[$ntt_post_num][0]; 
	$ntt_fc_info[$ntt_post_num][4] .= '" title="' . $ntt_fc_info[$ntt_post_num][0] . '" class="ntt_featured_thumb" /></div>';
	
	
	$ntt_post_num++;
endwhile;

// Reset wp_query to the default
$wp_query = null;
$wp_query = $temp;

for ($ntt_i = 1; $ntt_i <= $ntt_num_fc_pages; $ntt_i++)
{
	$ntt_start_post = ($ntt_i * 5) - 4;
	$ntt_end_post = ($ntt_i * 5);

	// Initialize beginning of page with the first title of first post
	$ntt_fc_page = '<div class="ntt_text_div"><div class="ntt_article_title">' . $ntt_fc_info[$ntt_start_post][0] . '</div><div class="ntt_horz_rule"></div><div class="ntt_article_excerpt">';
	
	for ($ntt_j = $ntt_start_post; $ntt_j <= $ntt_end_post; $ntt_j++)
	{
	
		$ntt_fc_page .= '<p title="';
	
		// Replace spaces in the title with dashes
		$ntt_temp_title = str_replace(' ', '-', $ntt_fc_info[$ntt_j][0]);
		
		// Make all the characters in the title lowercase
		$ntt_temp_title = strtolower($ntt_temp_title);
		
		// Place title into the title attribute for the paragraph
		$ntt_fc_page .= $ntt_temp_title . '">';
		
		// Retrieve the post excerpt
		$ntt_fc_page .= $ntt_fc_info[$ntt_j][1] . '</p>';
	
	}
	
	$ntt_fc_page .= '</div><div class="ntt_read_more">';

	// Create the read more tag and give it the first post url link
	// This will be changed dynamically by JQuery
		$ntt_fc_page .= '<a href="' . $ntt_fc_info[$ntt_start_post][2] . '">Read More</a>';
	
	$ntt_fc_page .= '</div></div><div class="ntt_featured_pic">';
	
	for ($ntt_j = $ntt_start_post; $ntt_j <= $ntt_end_post; $ntt_j++)
	{
		// Get the featured image, link to post and post title
		$ntt_fc_page .= '<a href="' . $ntt_fc_info[$ntt_j][2] . '" class="ntt_link_to_post" alt="' . $ntt_fc_info[$ntt_j][0] . '"><img src="' . $ntt_fc_info[$ntt_j][3] . '" alt="' . $ntt_fc_info[$ntt_j][0] . '" /></a>';
	}
	
	$ntt_fc_page .= '</div><div class="ntt_thumb_box">';
	
	// Create all of the thumbnails for the FC slider
	for ($ntt_j = $ntt_start_post; $ntt_j <= $ntt_end_post; $ntt_j++)
	{
	
		$ntt_fc_page .= '<div class="ntt_thumbnail_frame">';
		$ntt_fc_page .= $ntt_fc_info[$ntt_j][4];
	
	}
	
	// Place the left button on the screen
	$ntt_fc_page .= '</div><div class="ntt_left_button"><img src="';

	// Get the left button image by looking in the plugin directory
	$ntt_fc_page .= $ntt_plugin_directory . 'images/fc_left_arrow.png" alt="Back" /></div><div class="ntt_right_button"><img src="';
	
	// Get the right button image by looking in the plugin directory 
	$ntt_fc_page .= $ntt_plugin_directory . 'images/fc_right_arrow.png" alt="Next" /></div>';
	
	// Store the total number of featured slide pages in a hidden input
	$ntt_fc_page .= '<input type="hidden" name="ntt_total_fc_pages" value="' . $ntt_fc_pages . '" class="ntt_total_fc_pages">';
	
	// Get the location of the wordpress url folder
	$ntt_wordpress_url = get_bloginfo('wpurl');
	
	// Pass the location of the Wordpress url folder to the JS file with a 
	// hidden input tag
	$ntt_fc_page .= '<input type="hidden" name="ntt_wp_url_dir" value="' . $ntt_wordpress_url . '" class="ntt_wp_url_dir">';
	
	// When programming on a localhost you must reference the file directly
	$ntt_print_to = '/Library/WebServer/Documents/wordpress/wp-content/plugins/NTTFeaturedContent2/js/featured_data' . $ntt_start_post . '.txt';
	
	// Use the following if you're hosting this plugin not on localhost
	$ntt_print_test = '../wp-content/plugins/NTTFeaturedContent2/js/featured_data' . $ntt_start_post . '.txt';
	
	$ntt_print_to = realpath($ntt_print_test);

	if ($ntt_start_post == 1 || $ntt_start_post == 6 || $ntt_start_post == 11)
	{	
	// Open the file I'm going to write to. If it doesn't exist make it
	$ntt_fc_page_to_write = fopen($ntt_print_to, "w");
	
	// Write the updated info to the file
	fwrite($ntt_fc_page_to_write, $ntt_fc_page);
	
	// Close the file after finished with the file
	fclose($ntt_fc_page_to_write);
	}

}

}

?>
<?php
// When the post is saved call my function
add_action( 'save_post', 'ntt_mbe_image_save_meta' ); 

function ntt_mbe_image_save_meta( $post_id ) { 
//verify the metadata is set 
if ( isset( $_POST['ntt_mbe_image'] ) ) { 

// update_post_meta() updates the value of the image 
// esc_url_raw() sanitizes the url but doesn't encode HTML entities
update_post_meta( $post_id, '_ntt_mbe_image', esc_url_raw( $_POST['ntt_mbe_image'] ) ); 
} 

}
?>
<?php
// admin_print_scripts-post.php displays the post editor
// This is saying to call the custom function when the post editor is loaded
add_action('admin_print_scripts-post.php', 'ntt_mbe_image_admin_scripts'); add_action('admin_print_scripts-post-new.php', 'ntt_mbe_image_admin_scripts'); 

function ntt_mbe_image_admin_scripts() { 
	
	// wp_enqueue_script is used to embed javascript into a page
	// The array contains built in wordpress scripts that the javascript needs // to work
	wp_enqueue_script( 'ntt-image-upload', plugins_url( '/NTTFeaturedContent2/ntt-meta-image.js' ), array( 'jquery','media-upload','thickbox' ) );
} 
?>